@@ -1,34 +1,25 @@
 /****************************************************************************/
+// Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
+// Copyright (C) 2001-2020 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials are made available under the
+// terms of the Eclipse Public License 2.0 which is available at
+// https://www.eclipse.org/legal/epl-2.0/
+// This Source Code may also be made available under the following Secondary
+// Licenses when the conditions for such availability set forth in the Eclipse
+// Public License 2.0 are satisfied: GNU General Public License, version 2
+// or later which is available at
+// https://www.gnu.org/licenses/old-licenses/gpl-2.0-standalone.html
+// SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later
+/****************************************************************************/
 /// @file    GUILoadThread.cpp
 /// @author  Daniel Krajzewicz
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Sept 2002
-/// @version $Id: GUILoadThread.cpp 23974 2017-04-19 12:09:14Z laemmel $
 ///
 // Class describing the thread that performs the loading of a simulation
 /****************************************************************************/
-// SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
-/****************************************************************************/
-//
-//   This file is part of SUMO.
-//   SUMO is free software: you can redistribute it and/or modify
-//   it under the terms of the GNU General Public License as published by
-//   the Free Software Foundation, either version 3 of the License, or
-//   (at your option) any later version.
-//
-/****************************************************************************/
-
-
-// ===========================================================================
-// included modules
-// ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
 #include <config.h>
-#endif
 
 #include <iostream>
 #include <ctime>
@@ -39,7 +30,7 @@
 #include <utils/options/OptionsCont.h>
 #include <utils/options/Option.h>
 #include <utils/options/OptionsIO.h>
-#include <utils/foxtools/MFXEventQue.h>
+#include <utils/foxtools/FXSynchQue.h>
 #include <utils/gui/events/GUIEvent_Message.h>
 #include <utils/gui/windows/GUIAppEnum.h>
 #include <utils/gui/globjects/GUIGlObjectStorage.h>
@@ -59,24 +50,20 @@
 #include <microsim/MSGlobals.h>
 #include <microsim/MSFrame.h>
 #include <microsim/MSRouteHandler.h>
+#include <mesogui/GUIMEVehicleControl.h>
+#include <traci-server/TraCIServer.h>
+#include "TraCIServerAPI_GUI.h"
 #include "GUIApplicationWindow.h"
 #include "GUILoadThread.h"
 #include "GUIGlobals.h"
 #include "GUIEvent_SimulationLoaded.h"
 
-#include <mesogui/GUIMEVehicleControl.h>
-
-#ifndef NO_TRACI
-#include <traci-server/TraCIServer.h>
-#include "TraCIServerAPI_GUI.h"
-#endif
-
 
 // ===========================================================================
 // member method definitions
 // ===========================================================================
 GUILoadThread::GUILoadThread(FXApp* app, GUIApplicationWindow* mw,
-                             MFXEventQue<GUIEvent*>& eq, FXEX::FXThreadEvent& ev)
+                             FXSynchQue<GUIEvent*>& eq, FXEX::FXThreadEvent& ev)
     : FXSingleEventThread(app, mw), myParent(mw), myEventQue(eq),
       myEventThrow(ev) {
     myErrorRetriever = new MsgRetrievingFunction<GUILoadThread>(this, &GUILoadThread::retrieveMessage, MsgHandler::MT_ERROR);
@@ -103,29 +90,24 @@ GUILoadThread::run() {
     // try to load the given configuration
     OptionsCont& oc = OptionsCont::getOptions();
     try {
-        oc.clear();
-        MSFrame::fillOptions();
         if (myFile != "") {
             // triggered by menu option or reload
-            if (myLoadNet) {
-                oc.set("net-file", myFile);
-            } else {
-                oc.set("configuration-file", myFile);
-            }
+            oc.clear();
+            MSFrame::fillOptions();
+            oc.setByRootElement(OptionsIO::getRoot(myFile), myFile);
             oc.resetWritable(); // there may be command line options
             OptionsIO::getOptions();
         } else {
             // triggered at application start
-            OptionsIO::getOptions();
+            OptionsIO::loadConfiguration();
             if (oc.isSet("configuration-file")) {
                 myFile = oc.getString("configuration-file");
             } else if (oc.isSet("net-file")) {
                 myFile = oc.getString("net-file");
-                myLoadNet = true;
             }
-            myEventQue.add(new GUIEvent_Message("Loading '" + myFile + "'."));
+            myEventQue.push_back(new GUIEvent_Message("Loading '" + myFile + "'."));
             myEventThrow.signal();
-            myParent->addRecentFile(FXPath::absolute(myFile.c_str()), myLoadNet);
+            myParent->addRecentFile(FXPath::absolute(myFile.c_str()));
         }
         myTitle = myFile;
         // within gui-based applications, nothing is reported to the console
@@ -142,10 +124,11 @@ GUILoadThread::run() {
         if (!MSFrame::checkOptions()) {
             throw ProcessError();
         }
-        XMLSubSys::setValidation(oc.getString("xml-validation"), oc.getString("xml-validation.net"));
+        XMLSubSys::setValidation(oc.getString("xml-validation"), oc.getString("xml-validation.net"), oc.getString("xml-validation.routes"));
         GUIGlobals::gRunAfterLoad = oc.getBool("start");
         GUIGlobals::gQuitOnEnd = oc.getBool("quit-on-end");
         GUIGlobals::gDemoAutoReload = oc.getBool("demo");
+        GUIGlobals::gTrackerInterval = oc.getFloat("tracker-interval");
     } catch (ProcessError& e) {
         if (std::string(e.what()) != std::string("Process Error") && std::string(e.what()) != std::string("")) {
             WRITE_ERROR(e.what());
@@ -153,18 +136,16 @@ GUILoadThread::run() {
         // the options are not valid but maybe we want to quit
         GUIGlobals::gQuitOnEnd = oc.getBool("quit-on-end");
         MsgHandler::getErrorInstance()->inform("Quitting (on error).", false);
-        submitEndAndCleanup(0, 0, 0);
+        submitEndAndCleanup(nullptr, 0, 0);
         return 0;
     }
 
     // initialise global settings
-    RandHelper::initRandGlobal();
-    RandHelper::initRandGlobal(MSRouteHandler::getParsingRNG());
-    RandHelper::initRandGlobal(MSDevice::getEquipmentRNG());
+    NLBuilder::initRandomness();
     MSFrame::setMSGlobals(oc);
     GUITexturesHelper::allowTextures(!oc.getBool("disable-textures"));
 
-    MSVehicleControl* vehControl = 0;
+    MSVehicleControl* vehControl = nullptr;
     GUIVisualizationSettings::UseMesoSim = MSGlobals::gUseMesoSim;
     if (MSGlobals::gUseMesoSim) {
         vehControl = new GUIMEVehicleControl();
@@ -172,25 +153,23 @@ GUILoadThread::run() {
         vehControl = new GUIVehicleControl();
     }
 
-    GUINet* net = 0;
+    GUINet* net = nullptr;
     SUMOTime simStartTime = 0;
     SUMOTime simEndTime = 0;
     std::vector<std::string> guiSettingsFiles;
     bool osgView = false;
-    GUIEdgeControlBuilder* eb = 0;
+    GUIEdgeControlBuilder* eb = nullptr;
     try {
         net = new GUINet(
             vehControl,
             new GUIEventControl(),
             new GUIEventControl(),
             new GUIEventControl());
-#ifndef NO_TRACI
         // need to init TraCI-Server before loading routes to catch VEHICLE_STATE_BUILT
         std::map<int, TraCIServer::CmdExecutor> execs;
-        execs[CMD_GET_GUI_VARIABLE] = &TraCIServerAPI_GUI::processGet;
-        execs[CMD_SET_GUI_VARIABLE] = &TraCIServerAPI_GUI::processSet;
+        execs[libsumo::CMD_GET_GUI_VARIABLE] = &TraCIServerAPI_GUI::processGet;
+        execs[libsumo::CMD_SET_GUI_VARIABLE] = &TraCIServerAPI_GUI::processSet;
         TraCIServer::openSocket(execs);
-#endif
 
         eb = new GUIEdgeControlBuilder();
         GUIDetectorBuilder db(*net);
@@ -212,6 +191,15 @@ GUILoadThread::run() {
 #ifdef HAVE_OSG
             osgView = oc.getBool("osg-view");
 #endif
+            if (oc.isSet("edgedata-files")) {
+                if (!oc.isUsableFileList("edgedata-files")) {
+                    WRITE_ERROR("Could not load edgedata-files '" + oc.getString("edgedata-files") + "'");
+                } else {
+                    for (const std::string& file : oc.getStringVector("edgedata-files")) {
+                        net->loadEdgeData(file);
+                    }
+                }
+            }
         }
     } catch (ProcessError& e) {
         if (std::string(e.what()) != std::string("Process Error") && std::string(e.what()) != std::string("")) {
@@ -219,19 +207,20 @@ GUILoadThread::run() {
         }
         MsgHandler::getErrorInstance()->inform("Quitting (on error).", false);
         delete net;
-        net = 0;
+        net = nullptr;
 #ifndef _DEBUG
     } catch (std::exception& e) {
         WRITE_ERROR(e.what());
         delete net;
-        net = 0;
+        net = nullptr;
 #endif
     }
-    if (net == 0) {
+    if (net == nullptr) {
         MSNet::clearAll();
     }
     delete eb;
-    submitEndAndCleanup(net, simStartTime, simEndTime, guiSettingsFiles, osgView);
+    submitEndAndCleanup(net, simStartTime, simEndTime, guiSettingsFiles, osgView,
+                        oc.getBool("registry-viewport"));
     return 0;
 }
 
@@ -241,24 +230,24 @@ GUILoadThread::submitEndAndCleanup(GUINet* net,
                                    const SUMOTime simStartTime,
                                    const SUMOTime simEndTime,
                                    const std::vector<std::string>& guiSettingsFiles,
-                                   const bool osgView) {
+                                   const bool osgView,
+                                   const bool viewportFromRegistry) {
     // remove message callbacks
     MsgHandler::getErrorInstance()->removeRetriever(myErrorRetriever);
     MsgHandler::getWarningInstance()->removeRetriever(myWarningRetriever);
     MsgHandler::getMessageInstance()->removeRetriever(myMessageRetriever);
     // inform parent about the process
-    GUIEvent* e = new GUIEvent_SimulationLoaded(net, simStartTime, simEndTime, myTitle, guiSettingsFiles, osgView);
-    myEventQue.add(e);
+    GUIEvent* e = new GUIEvent_SimulationLoaded(net, simStartTime, simEndTime, myTitle, guiSettingsFiles, osgView, viewportFromRegistry);
+    myEventQue.push_back(e);
     myEventThrow.signal();
 }
 
 
 void
-GUILoadThread::loadConfigOrNet(const std::string& file, bool isNet) {
+GUILoadThread::loadConfigOrNet(const std::string& file) {
     myFile = file;
-    myLoadNet = isNet;
     if (myFile != "") {
-        OptionsIO::setArgs(0, 0);
+        OptionsIO::setArgs(0, nullptr);
     }
     start();
 }
@@ -267,7 +256,7 @@ GUILoadThread::loadConfigOrNet(const std::string& file, bool isNet) {
 void
 GUILoadThread::retrieveMessage(const MsgHandler::MsgType type, const std::string& msg) {
     GUIEvent* e = new GUIEvent_Message(type, msg);
-    myEventQue.add(e);
+    myEventQue.push_back(e);
     myEventThrow.signal();
 }
 
