@@ -1,36 +1,26 @@
 /****************************************************************************/
+// Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
+// Copyright (C) 2001-2020 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials are made available under the
+// terms of the Eclipse Public License 2.0 which is available at
+// https://www.eclipse.org/legal/epl-2.0/
+// This Source Code may also be made available under the following Secondary
+// Licenses when the conditions for such availability set forth in the Eclipse
+// Public License 2.0 are satisfied: GNU General Public License, version 2
+// or later which is available at
+// https://www.gnu.org/licenses/old-licenses/gpl-2.0-standalone.html
+// SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later
+/****************************************************************************/
 /// @file    NIXMLNodesHandler.h
 /// @author  Daniel Krajzewicz
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Tue, 20 Nov 2001
-/// @version $Id: NIXMLNodesHandler.h 22608 2017-01-17 06:28:54Z behrisch $
 ///
 // Importer for network nodes stored in XML
 /****************************************************************************/
-// SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
-/****************************************************************************/
-//
-//   This file is part of SUMO.
-//   SUMO is free software: you can redistribute it and/or modify
-//   it under the terms of the GNU General Public License as published by
-//   the Free Software Foundation, either version 3 of the License, or
-//   (at your option) any later version.
-//
-/****************************************************************************/
-#ifndef NIXMLNodesHandler_h
-#define NIXMLNodesHandler_h
-
-
-// ===========================================================================
-// included modules
-// ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
+#pragma once
 #include <config.h>
-#endif
 
 #include <utils/xml/SUMOSAXHandler.h>
 #include <utils/geom/Position.h>
@@ -68,7 +58,7 @@ public:
      * @todo Options are only given to determine whether "flip-y" is set; maybe this should be done by giving a bool
      * @todo Why are options not const?
      */
-    NIXMLNodesHandler(NBNodeCont& nc, NBTrafficLightLogicCont& tlc,
+    NIXMLNodesHandler(NBNodeCont& nc, NBEdgeCont& ec, NBTrafficLightLogicCont& tlc,
                       OptionsCont& options);
 
 
@@ -77,9 +67,10 @@ public:
 
     /** @brief parses node attributes (not related to positioning)
      */
-    static void processNodeType(const SUMOSAXAttributes& attrs, NBNode* node, const std::string& nodeID, const Position& position,
-                                bool updateEdgeGeometries,
-                                NBNodeCont& nc, NBTrafficLightLogicCont& tlc);
+    static NBNode* processNodeType(const SUMOSAXAttributes& attrs, NBNode* node, const std::string& nodeID, const Position& position,
+                                   bool updateEdgeGeometries,
+                                   NBNodeCont& nc, NBEdgeCont& ec,
+                                   NBTrafficLightLogicCont& tlc);
 
 protected:
     /// @name inherited from GenericSAXHandler
@@ -97,6 +88,13 @@ protected:
      */
     void myStartElement(int element,
                         const SUMOSAXAttributes& attrs);
+    /** @brief Called when a closing tag occurs
+     *
+     * @param[in] element ID of the currently opened element
+     * @exception ProcessError If something fails
+     * @see GenericSAXHandler::myEndElement
+     */
+    void myEndElement(int element);
     //@}
 
 
@@ -147,12 +145,17 @@ private:
     /// @brief The node container to add built nodes to
     NBNodeCont& myNodeCont;
 
+    /// @brief The node container to add built nodes to
+    NBEdgeCont& myEdgeCont;
+
     /// @brief The traffic lights container to add built tls to
     NBTrafficLightLogicCont& myTLLogicCont;
 
     /// @brief The coordinate transformation which was used compute the node coordinates
     GeoConvHelper* myLocation;
 
+    /// @brief last item the could receive parameters
+    Parameterised* myLastParameterised;
 
 private:
     /** @brief invalid copy constructor */
@@ -162,9 +165,3 @@ private:
     NIXMLNodesHandler& operator=(const NIXMLNodesHandler& s);
 
 };
-
-
-#endif
-
-/****************************************************************************/
-
