@@ -1,36 +1,27 @@
 /****************************************************************************/
+// Eclipse SUMO, Simulation of Urban MObility; see https://eclipse.org/sumo
+// Copyright (C) 2001-2020 German Aerospace Center (DLR) and others.
+// This program and the accompanying materials are made available under the
+// terms of the Eclipse Public License 2.0 which is available at
+// https://www.eclipse.org/legal/epl-2.0/
+// This Source Code may also be made available under the following Secondary
+// Licenses when the conditions for such availability set forth in the Eclipse
+// Public License 2.0 are satisfied: GNU General Public License, version 2
+// or later which is available at
+// https://www.gnu.org/licenses/old-licenses/gpl-2.0-standalone.html
+// SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later
+/****************************************************************************/
 /// @file    NWWriter_SUMO.h
 /// @author  Daniel Krajzewicz
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
+/// @author  Leonhard Luecken
 /// @date    Tue, 04.05.2011
-/// @version $Id: NWWriter_SUMO.h 23150 2017-02-27 12:08:30Z behrisch $
 ///
 // Exporter writing networks using the SUMO format
 /****************************************************************************/
-// SUMO, Simulation of Urban MObility; see http://sumo.dlr.de/
-// Copyright (C) 2001-2017 DLR (http://www.dlr.de/) and contributors
-/****************************************************************************/
-//
-//   This file is part of SUMO.
-//   SUMO is free software: you can redistribute it and/or modify
-//   it under the terms of the GNU General Public License as published by
-//   the Free Software Foundation, either version 3 of the License, or
-//   (at your option) any later version.
-//
-/****************************************************************************/
-#ifndef NWWriter_SUMO_h
-#define NWWriter_SUMO_h
-
-
-// ===========================================================================
-// included modules
-// ===========================================================================
-#ifdef _MSC_VER
-#include <windows_config.h>
-#else
+#pragma once
 #include <config.h>
-#endif
 
 #include <string>
 #include <map>
@@ -46,6 +37,7 @@
 class OutputDevice;
 class OptionsCont;
 class NBNetBuilder;
+class NBTrafficLightLogic;
 class NBTrafficLightLogicCont;
 class NBNode;
 class NBDistrict;
@@ -85,7 +77,7 @@ public:
      * @param[in] plain Whether only plain-xml output should be written (omit some attributes)
      */
     static void writeConnection(OutputDevice& into, const NBEdge& from, const NBEdge::Connection& c,
-                                bool includeInternal, ConnectionStyle style = SUMONET);
+                                bool includeInternal, ConnectionStyle style = SUMONET, bool geoAccuracy = false);
 
     /// @brief writes the given prohibitions
     static void writeProhibitions(OutputDevice& into, const NBConnectionProhibits& prohibitions);
@@ -93,6 +85,9 @@ public:
     /// @brief writes the traffic light logics to the given device
     static void writeTrafficLights(OutputDevice& into, const NBTrafficLightLogicCont& tllCont);
 
+    /// @brief writes a single traffic light logic to the given device
+    static void writeTrafficLight(OutputDevice& into, const NBTrafficLightLogic* logic);
+
     /** @brief Writes roundabouts
      * @param[in] into The device to write the edge into
      * @param[in] roundaboutes The roundabouts to write
@@ -101,27 +96,37 @@ public:
     static void writeRoundabouts(OutputDevice& into, const std::set<EdgeSet>& roundabouts,
                                  const NBEdgeCont& ec);
 
-protected:
+
+    /** @brief Write a stopOffset element into output device
+     */
+    static void writeStopOffsets(OutputDevice& into, const std::map<SVCPermissions, double>& stopOffsets);
+
+    /** @brief Writes a district
+     * @param[in] into The device to write the edge into
+     * @param[in] d The district
+     */
+    static void writeDistrict(OutputDevice& into, const NBDistrict& d);
+
+
+private:
     /// @name Methods for writing network parts
     /// @{
 
     /** @brief Writes internal edges (<edge ... with id[0]==':') of the given node
      * @param[in] into The device to write the edges into
      * @param[in] n The node to write the edges of
-     * @param[in] origNames Whether original names shall be written as parameter
      * @return Whether an internal edge was written
      */
-    static bool writeInternalEdges(OutputDevice& into, const NBEdgeCont& ec, const NBNode& n, bool origNames);
+    static bool writeInternalEdges(OutputDevice& into, const NBEdgeCont& ec, const NBNode& n);
 
 
     /** @brief Writes an edge (<edge ...)
      * @param[in] into The device to write the edge into
      * @param[in] e The edge to write
      * @param[in] noNames Whether names shall be ignored
-     * @param[in] origNames Whether original names shall be written as parameter
      * @see writeLane()
      */
-    static void writeEdge(OutputDevice& into, const NBEdge& e, bool noNames, bool origNames);
+    static void writeEdge(OutputDevice& into, const NBEdge& e, bool noNames);
 
 
     /** @brief Writes a lane (<lane ...) of an edge
@@ -130,24 +135,25 @@ protected:
      * @param[in] origID The original ID of the edge in the input
      * @param[in] length Lane's length
      * @param[in] index The index of the lane within the edge
-     * @param[in] origNames Whether original names shall be written as parameter
      * @param[in] oppositeID The ID of the opposite lane for overtaking
-     * @param[in] node The node to check for custom shape data
      * @param[in] accelRamp whether this lane is an acceleration lane
+     * @param[in] customShape whether this lane has a custom shape
      */
     static void writeLane(OutputDevice& into, const std::string& lID,
                           double speed, SVCPermissions permissions, SVCPermissions preferred,
-                          double endOffset, double width, PositionVector shape,
-                          const std::string& origID, double length, int index, bool origNames,
-                          const std::string& oppositeID, const NBNode* node = 0, bool accelRamp = false);
+                          double startOffset, double endOffset,
+                          std::map<SVCPermissions, double> stopOffsets, double width, PositionVector shape,
+                          const Parameterised* params, double length, int index,
+                          const std::string& oppositeID, const std::string& type,
+                          bool accelRamp = false,
+                          bool customShape = false);
 
 
     /** @brief Writes a junction (<junction ...)
      * @param[in] into The device to write the edge into
      * @param[in] n The junction/node to write
-     * @param[in] checkLaneFoes Whether laneConflicts shall be checked at this junction
      */
-    static void writeJunction(OutputDevice& into, const NBNode& n, const bool checkLaneFoes);
+    static void writeJunction(OutputDevice& into, const NBNode& n);
 
 
     /** @brief Writes internal junctions (<junction with id[0]==':' ...) of the given node
@@ -164,13 +170,6 @@ protected:
     static bool writeInternalConnections(OutputDevice& into, const NBNode& n);
 
 
-    /** @brief Writes a district
-     * @param[in] into The device to write the edge into
-     * @param[in] d The district
-     */
-    static void writeDistrict(OutputDevice& into, const NBDistrict& d);
-
-private:
     /** @brief Writes a single internal connection
      * @param[in] from The id of the from-edge
      * @param[in] to The id of the to-edge
@@ -179,7 +178,10 @@ private:
      */
     static void writeInternalConnection(OutputDevice& into,
                                         const std::string& from, const std::string& to,
-                                        int fromLane, int toLane, const std::string& via);
+                                        int fromLane, int toLane, const std::string& via,
+                                        LinkDirection dir = LinkDirection::STRAIGHT,
+                                        const std::string& tlID = "",
+                                        int linkIndex = NBConnection::InvalidTlIndex);
 
     /// @brief writes a SUMOTime as int if possible, otherwise as a float
     static std::string writeSUMOTime(SUMOTime time);
@@ -197,12 +199,6 @@ private:
                                 const NBEdgeCont& ec);
 
     /// @brief retrieve the id of the opposite direction internal lane if it exists
-    static std::string getOppositeInternalID(const NBEdgeCont& ec, const NBEdge* from, const NBEdge::Connection& con);
+    static std::string getOppositeInternalID(const NBEdgeCont& ec, const NBEdge* from, const NBEdge::Connection& con, double& oppositeLength);
 
 };
-
-
-#endif
-
-/****************************************************************************/
-
